--[[ LogisticTrainOrganizer
  * Copyright (c) 2019 Goswin von Brederlow
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
--]]

local function player_setup_blueprint(event)
  log("player_setup_blueprint")
  log(serpent.block(event))
  local player = game.players[event.player_index]
  local bp = player.blueprint_to_setup
  if not bp or not bp.valid_for_read then
    bp = player.cursor_stack
  end
  if not bp or not bp.valid_for_read then
    return
  end
  local entities = bp.get_blueprint_entities()
  if not entities then
    return
  end
  for i, entity in ipairs(entities) do
    if entity.name == "tag-chest" then
      log("blueprint entity " .. i .. ": " .. serpent.block(entity))
      bp.set_blueprint_entity_tag(i, "example-tag", 23)
      log("example-tag = " .. serpent.block(bp.get_blueprint_entity_tag(i, "example-tag")))
    end
  end
  for i, entity in ipairs(player.surface.find_entities(event.area)) do
    if entity.name == "tag-chest" then
      log("map entity " .. i .. ": " .. serpent.block(entity.position))
    end
  end
end

function entity_built(event)
  local entity = event.created_entity
  log("entity_built: " .. entity.name)
  if entity and entity.name == "tag-chest" then
    log("tag-chest")
    local tags = event.tags
    if tags then
      log("with tags")
      local data = tags["example-tag"]
      if data then
        log("Entity build with example example-tag " .. data)
      else
        log("example-tag missing")
      end
    else
      log("tags missing")
    end
  end
end
  
script.on_event(defines.events.on_player_setup_blueprint, player_setup_blueprint)
script.on_event(defines.events.on_built_entity, entity_built)
script.on_event(defines.events.on_robot_built_entity, entity_built)
script.on_event(defines.events.script_raised_built, entity_built)
